==> aws-cdk.aws-dynamodb-1.117.0.tar.gz: package/lib/dynamodb-canned-metrics.generated.d.ts <==
export declare class DynamoDBMetrics {
    static userErrorsSum(dimensions: {
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            TableName: string;
        };
        statistic: string;
    };
    static throttledRequestsSum(dimensions: {
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            TableName: string;
        };
        statistic: string;
    };
    static consumedReadCapacityUnitsSum(dimensions: {
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            TableName: string;
        };
        statistic: string;
    };
    static provisionedReadCapacityUnitsSum(dimensions: {
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            TableName: string;
        };
        statistic: string;
    };
    static consumedWriteCapacityUnitsSum(dimensions: {
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            TableName: string;
        };
        statistic: string;
    };
    static provisionedWriteCapacityUnitsSum(dimensions: {
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            TableName: string;
        };
        statistic: string;
    };
    static successfulRequestLatencyAverage(dimensions: {
        Operation: string;
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            Operation: string;
            TableName: string;
        };
        statistic: string;
    };
    static returnedBytesAverage(dimensions: {
        Operation: string;
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            Operation: string;
            TableName: string;
        };
        statistic: string;
    };
    static returnedItemCountSum(dimensions: {
        Operation: string;
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            Operation: string;
            TableName: string;
        };
        statistic: string;
    };
}

==> aws-cdk.aws-dynamodb-1.138.2.tar.gz: package/lib/dynamodb-canned-metrics.generated.d.ts <==
export declare class DynamoDBMetrics {
    static userErrorsSum(dimensions: {
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            TableName: string;
        };
        statistic: string;
    };
    static throttledRequestsSum(dimensions: {
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            TableName: string;
        };
        statistic: string;
    };
    static consumedReadCapacityUnitsSum(dimensions: {
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            TableName: string;
        };
        statistic: string;
    };
    static provisionedReadCapacityUnitsSum(dimensions: {
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            TableName: string;
        };
        statistic: string;
    };
    static consumedWriteCapacityUnitsSum(dimensions: {
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            TableName: string;
        };
        statistic: string;
    };
    static provisionedWriteCapacityUnitsSum(dimensions: {
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            TableName: string;
        };
        statistic: string;
    };
    static successfulRequestLatencyAverage(dimensions: {
        Operation: string;
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            Operation: string;
            TableName: string;
        };
        statistic: string;
    };
    static returnedBytesAverage(dimensions: {
        Operation: string;
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            Operation: string;
            TableName: string;
        };
        statistic: string;
    };
    static returnedItemCountSum(dimensions: {
        Operation: string;
        TableName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            Operation: string;
            TableName: string;
        };
        statistic: string;
    };
}
